# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: mb_protocol_enums.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'mb_protocol_enums.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17mb_protocol_enums.proto\x12\x15wmb.proto.mb_protocol*V\n\nModbusMode\x12\x17\n\x13MODBUS_MODE_UNKNOWN\x10\x00\x12\x16\n\x12MODBUS_MODE_MASTER\x10\x01\x12\x17\n\x13MODBUS_MODE_SNIFFER\x10\x02*R\n\x0f\x41ntennaSettings\x12\x13\n\x0f\x41NTENNA_UNKNOWN\x10\x00\x12\x14\n\x10\x41NTENNA_INTERNAL\x10\x01\x12\x14\n\x10\x41NTENNA_EXTERNAL\x10\x02*P\n\nModbusPort\x12\x17\n\x13MODBUS_PORT_UNKNOWN\x10\x00\x12\x14\n\x10MODBUS_PORT_ZERO\x10\x01\x12\x13\n\x0fMODBUS_PORT_ONE\x10\x02*\xc8\x01\n\x08PortBaud\x12\x15\n\x11PORT_BAUD_UNKNOWN\x10\x00\x12\x12\n\x0ePORT_BAUD_4800\x10\x0c\x12\x12\n\x0ePORT_BAUD_9600\x10\r\x12\x13\n\x0fPORT_BAUD_19200\x10\x0e\x12\x13\n\x0fPORT_BAUD_28800\x10\x0f\x12\x13\n\x0fPORT_BAUD_38400\x10\x10\x12\x13\n\x0fPORT_BAUD_57600\x10\x11\x12\x13\n\x0fPORT_BAUD_76800\x10\x12\x12\x14\n\x10PORT_BAUD_115200\x10\x13*\x93\x01\n\nPortParity\x12\x17\n\x13PORT_PARITY_UNKNOWN\x10\x00\x12\x14\n\x10PORT_PARITY_NONE\x10\x01\x12\x13\n\x0fPORT_PARITY_ODD\x10\x02\x12\x14\n\x10PORT_PARITY_EVEN\x10\x03\x12\x14\n\x10PORT_PARITY_MARK\x10\x04\x12\x15\n\x11PORT_PARITY_SPACE\x10\x05*\x86\x01\n\x0cPortStopBits\x12\x1a\n\x16PORT_STOP_BITS_UNKNOWN\x10\x00\x12\x16\n\x12PORT_STOP_BITS_0_5\x10\x01\x12\x14\n\x10PORT_STOP_BITS_1\x10\x02\x12\x16\n\x12PORT_STOP_BITS_1_5\x10\x03\x12\x14\n\x10PORT_STOP_BITS_2\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mb_protocol_enums_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODBUSMODE']._serialized_start=50
  _globals['_MODBUSMODE']._serialized_end=136
  _globals['_ANTENNASETTINGS']._serialized_start=138
  _globals['_ANTENNASETTINGS']._serialized_end=220
  _globals['_MODBUSPORT']._serialized_start=222
  _globals['_MODBUSPORT']._serialized_end=302
  _globals['_PORTBAUD']._serialized_start=305
  _globals['_PORTBAUD']._serialized_end=505
  _globals['_PORTPARITY']._serialized_start=508
  _globals['_PORTPARITY']._serialized_end=655
  _globals['_PORTSTOPBITS']._serialized_start=658
  _globals['_PORTSTOPBITS']._serialized_end=792
# @@protoc_insertion_point(module_scope)
